"""Docstring is good.
"""


def test_happy(function_xfile, module_xfile, package_xfile):
    print("function_xfile", function_xfile)
    print("module_xfile", module_xfile)
    print("package_xfile", package_xfile)


def test_jsonfile(function_json, module_json, package_json):
    print("function_json", function_json)
    print("module_json", module_json)
    print("package_json", package_json)
